Summary: 	GNU libraries and utilities for producing multi-lingual messages.
Name: 		gettext
Version: 	0.19.8.1
Release:	1 
License: 	GPLv3 and LGPLv2+
Group: 		Development/Tools
URL: 		http://www.gnu.org/software/%{name}/
Source0: 	ftp://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
Source1: 	ftp://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz.sig
Source2: 	libintl.so.1-aix32
Source3: 	libintl.so.1-aix64
Patch0:         %{name}-0.19.7-aixconf.patch
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:	libiconv >= 1.15-1
BuildRequires:	make, patch

Requires:	libiconv >= 1.15-1

%ifos aix6.1
Requires: AIX-rpm >= 6.1.0.0
%endif

%define _libdir64 %{_prefix}/lib64

%description
The GNU gettext package provides a set of tools and documentation for
producing multi-lingual messages in programs. Tools include a set of
conventions about how programs should be written to support message
catalogs, a directory and file naming organization for the message
catalogs, a runtime library which supports the retrieval of translated
messages, and stand-alone programs for handling the translatable and
the already translated strings. Gettext provides an easy to use
library and tools for creating, using, and modifying natural language
catalogs and is a powerful and simple method for internationalizing
programs.

The library is available as 32-bit and 64-bit.


%package devel
Summary:	Development files for %{name}
Group:		Development/Tools
License:	LGPLv2+
Requires:	%{name} = %{version}-%{release}

%description devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add gettext support for your project.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%prep
export PATH=/opt/freeware/bin:$PATH
%setup -q
%patch0 -p1 -b .aixconf
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export RM="/usr/bin/rm -f"

export CC="xlc_r"
export CXX="xlC_r"

# first build the 64-bit version
cd 64bit
export OBJECT_MODE=64
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --infodir=%{_infodir} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static \
    --without-libiconv-prefix \
    --with-included-gettext \
    --with-included-glib \
    --with-included-libxml
gmake %{?_smp_mflags}

# now build the 32-bit version
cd ../32bit
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --infodir=%{_infodir} \
    --mandir=%{_mandir} \
    --enable-shared --disable-static \
    --without-libiconv-prefix \
    --with-included-gettext \
    --with-included-glib \
    --with-included-libxml
gmake %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
  mv gettext.sh_64 gettext_64.sh
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libasprintf.a ${RPM_BUILD_ROOT}%{_libdir64}/libasprintf.so.0
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libgettextlib.a ${RPM_BUILD_ROOT}%{_libdir64}/libgettextlib-0.19.8.1.so
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libgettextsrc.a ${RPM_BUILD_ROOT}%{_libdir64}/libgettextsrc-0.19.8.1.so
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libgettextpo.a ${RPM_BUILD_ROOT}%{_libdir64}/libgettextpo.so.0
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libintl.a ${RPM_BUILD_ROOT}%{_libdir64}/libintl.so.8

# Add the older libintl.so.1 shared members for compatibility with older apps
# (make sure they're set for LOADONLY with 'strip -e')
/usr/bin/strip -X32 -e %{SOURCE2}
/usr/bin/strip -X64 -e %{SOURCE3}
cp %{SOURCE2} libintl.so.1
/usr/bin/ar -X32 -q ${RPM_BUILD_ROOT}%{_libdir}/libintl.a libintl.so.1
cp %{SOURCE3} libintl.so.1
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libintl.a libintl.so.1

rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
gzip --best ${RPM_BUILD_ROOT}%{_infodir}/*info*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%post
/sbin/install-info %{_infodir}/gettext.info.gz %{_infodir}/dir || :

%preun
if [ "$1" = 0 ]; then
    /sbin/install-info --delete %{_infodir}/gettext.info.gz %{_infodir}/dir || :
fi


%post devel
/sbin/install-info %{_infodir}/autosprintf.info.gz %{_infodir}/dir || :

%preun devel
if [ "$1" = 0 ]; then
    /sbin/install-info --delete %{_infodir}/autosprintf.info.gz %{_infodir}/dir || :
fi


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc 32bit/gettext-runtime/ABOUT-NLS 32bit/AUTHORS 32bit/gettext-runtime/BUGS
%doc 32bit/COPYING 32bit/gettext-tools/misc/DISCLAIM 32bit/README
%doc 32bit/NEWS 32bit/THANKS
%doc 32bit/gettext-runtime/man/*.1.html
%doc 32bit/gettext-runtime/intl/COPYING*
%{_bindir}/[emnrx]*
%{_bindir}/gettext
%{_bindir}/gettext_64
%{_bindir}/gettext.sh
%{_bindir}/gettext_64.sh
%{_libdir}/libintl.a
%{_libdir64}/libintl.a
%{_libdir}/libgettextlib*.a
%{_libdir64}/libgettextlib*.a
%{_libdir}/libgettextsrc*.a
%{_libdir64}/libgettextsrc*.a
%{_libdir}/%{name}
%{_libdir64}/%{name}
%{_infodir}/gettext*
%{_mandir}/man1/[emnrx]*
%{_mandir}/man1/gettext.1
%{_datadir}/locale/*/*/*
/usr/bin/[emnrx]*
/usr/bin/gettext
/usr/bin/gettext_64
/usr/bin/gettext.sh
/usr/bin/gettext_64.sh
/usr/lib/libintl.a
/usr/lib64/libintl.a
/usr/lib/libgettextlib*.a
/usr/lib64/libgettextlib*.a
/usr/lib/libgettextsrc*.a
/usr/lib64/libgettextsrc*.a


%files devel
%defattr(-,root,system,-)
%doc 32bit/gettext-runtime/man/*.3.html 32bit/ChangeLog
%doc 32bit/gettext-runtime/intl-java/javadoc*
%{_bindir}/autopoint*
%{_bindir}/gettextize*
%{_bindir}/recode-sr-latin*
%{_includedir}/*
%{_libdir}/libasprintf.a
%{_libdir}/libgettextpo.a
%{_libdir}/*.la
%{_libdir64}/*.la
%{_mandir}/man1/autopoint.1
%{_mandir}/man1/gettextize.1
%{_mandir}/man1/recode-sr-latin.1
%{_mandir}/man3/*
%{_infodir}/autosprintf*
%{_datadir}/aclocal/*
%{_datadir}/%{name}
/usr/bin/autopoint*
/usr/bin/gettextize*
/usr/bin/recode-sr-latin*
/usr/include/*
/usr/lib/libasprintf.a
/usr/lib64/libasprintf.a
/usr/lib/libgettextpo.a
/usr/lib64/libgettextpo.a
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Wed Oct 17 2018 Michael Perzl <michael@perzl.org> - 0.19.8.1-1
- updated to version 0.19.8.1

* Thu Mar 13 2008 Michael Perzl <michael@perzl.org> - 0.17-1
- first version for AIX V5.1 and higher
